/// <reference types="react" />
import { Component, ReactNode } from "react";
import { TableProps, TableColumnConfig } from "antd/es/table/Table";
import { PaginationProps } from "antd/es/pagination";
export interface RColumnsProps<T> extends TableColumnConfig<T> {
    defaultVisible?: boolean;
    visible?: boolean;
    maxWidth?: number;
    tooltip?: boolean;
    renderTooltip?(text?: any, record?: any, index?: number): ReactNode;
}
export interface ExportOptions {
    enabled?: boolean;
    btnText?: string;
    clickType?: "default" | "configurable";
    configModalTitle?: ReactNode;
    configModalPrev?: ReactNode;
    configModalExtra?: ReactNode;
    rangeTypes?: string[];
}
export interface OnExportOptions {
    checkedColumnKeys?: string[];
    columnsType?: "ALL" | "PARTIAL";
    rangeType?: "ALL" | "SELECTED" | "RESULT";
}
export interface RPagination extends PaginationProps {
    type?: "default" | "prev_next";
    onPrevClick?(pageNo?: number, pageSize?: number): void;
    onNextClick?(pageNo?: number, pageSize?: number): void;
}
export interface RTableProps<T> extends TableProps<T> {
    cardTitle?: ReactNode;
    showEditColumns?: boolean;
    showExport?: boolean;
    exportType?: "by-one-click" | "by-config";
    exportOptions?: ExportOptions;
    fixedMaxWidth?: boolean;
    columns: Array<RColumnsProps<T>>;
    pagination?: RPagination | boolean;
    onExport?(options: OnExportOptions): void | boolean;
}
export interface RTableState {
    shouldRemoveColumnFixedProps: boolean;
    invisibleColumnKeys: string[];
}
export interface TableContext {
    antLocale?: {
        Table?: any;
    };
}
export declare class RTable<T> extends Component<RTableProps<T>, RTableState> {
    static defaultProps: Partial<RTableProps<{}>>;
    static contextTypes: {
        antLocale: any;
    };
    context: TableContext;
    state: RTableState;
    private table;
    componentDidMount(): void;
    getLocale(): {
        editColumnsBtnText: string;
        exportBtnText: string;
        exportModal: {
            submitText: string;
        };
        columnsType: {
            text: string;
            all: string;
            partial: string;
        };
        rangeType: {
            text: string;
            all: string;
            selected: string;
            result: string;
        };
        prevNext: {
            prevText: string;
            nextText: string;
        };
    } | {
        constructor: Function;
        toString(): string;
        toLocaleString(): string;
        valueOf(): Object;
        hasOwnProperty(v: string): boolean;
        hasOwnProperty(v: PropertyKey): boolean;
        isPrototypeOf(v: Object): boolean;
        propertyIsEnumerable(v: string): boolean;
        propertyIsEnumerable(v: PropertyKey): boolean;
        editColumnsBtnText: string;
        exportBtnText: string;
        exportModal: {
            submitText: string;
        };
        columnsType: {
            text: string;
            all: string;
            partial: string;
        };
        rangeType: {
            text: string;
            all: string;
            selected: string;
            result: string;
        };
        prevNext: {
            prevText: string;
            nextText: string;
        };
    };
    getPagination: () => any;
    fixColumnFixed: () => void;
    handleCheckedColumnKeysChange: (checked: boolean, curColumnKey: string) => () => void;
    renderEditColumnsAction: () => JSX.Element | null;
    renderExportAction: () => JSX.Element | null;
    renderCardTitle: () => JSX.Element;
    renderCardExtra: () => JSX.Element;
    onPrevClick: () => void;
    onNextClick: () => void;
    renderPrevNextAction: () => JSX.Element | null;
    render(): JSX.Element;
}
export default RTable;
